@@ -117,31 +117,35 @@ bland.altman.stats <- function(group1, group2, two=1.96, mode=1, conf.int=.95){
 #' Produce Bland-Altman Plot
 #'  
 #' Bland-AltmanPlots for assessing agreement between two measuring methods or
-#' repeatability (test-retest agreement) of measurements. Focus on base graphics
-#' but ggplot2 is available, for consistency with your other plots. No ggvis 
-#' available so far.
+#' repeatability (test-retest agreement) of measurements. Using either base graphics
+#' or ggplot2.
 #' @param group1 Measurements with first method or first measurement
 #' @param group2 Measurements with second method or second measurement
 #' @param two Lines are drawn "two" standard deviations from mean differences.
 #' This defaults to 1.96 for proper 95 percent confidence interval estimation
-#' but can be set to 2.0.
+#' but can be set to 2.0 for better agreement with e. g. the Bland Altman publication.
 #' @param mode if 1 then difference group1 minus group2 is used, if 2 then
 #' group2 minus group1 is used. Defaults to 1.
 #' @param graph.sys Graphing system within R. This defaults to "base" but can be
-#' one out of \code{c("base", "ggplot2")}. At the time given, only "base" will 
-#' provide full functionality. There is however some ggplot2 functionality (see examples).
+#' one out of \code{c("base", "ggplot2")}, providing ggplot2 is installed.
 #' @param conf.int Defaults to 0 which draws the usual Bland Altman plot which 
 #' contains no confidence intervalls. Change to .95 for 95 percent confidence
 #' intervalls to be drawn.
-#' @param silent logical. If TRUE then no return value. If FALSE then returns 
-#' statistics
+#' @param silent logical. If graph.sys=="base" and silent==TRUE then no return value. 
+#' If graph.sys=="base" and silent==FALSE then returns statistics.
 #' @param sunflower logical. If TRUE, the plot will be based on a sunflower plot
 #' and ties will be marked accordingly. Try with data with ties. Works only with
 #' \code{graph.sys=="base"}.
+#' @param geom_count logical. If TRUE, the dots will get larger the more frequent
+#' given pair is. Use in presence of ties. Works only with
+#' \code{graph.sys=="ggplot2"} version >=2.0.0.
 #' @param ... passed on to graphics functions if \code{graph.sys=="base"}
 #' @author Bernhard Lehnert <bernhard.lehnert@@uni-greifswald.de>
-#' @return If silent==TRUE no returns. If silent==FALSE than returns list of
-#' statistics as returned by \code{bland.altman.stats()}.
+#' @return Depends on graphic system chosen. In case of "base" depending on whether
+#' silent==TRUE. If silent==TRUE then no returns. If silent==FALSE than returns
+#' list of statistics as returned by \code{bland.altman.stats()}. In case the 
+#' graphics system is "ggplot2" than the graphic object is returned so that it 
+#' can be printed or altered.
 #' @seealso \code{\link{bland.altman.stats}}
 #' @export
 #' @examples
@@ -154,7 +158,7 @@ bland.altman.stats <- function(group1, group2, two=1.96, mode=1, conf.int=.95){
 #' bland.altman.plot(rnorm(200), 2+.8*rnorm(200), xlab="mean measurement", 
 #'                   ylab="differences", conf.int=.95)
 #'                   
-#' # this is what fig.2 in Bland&Altman1986 whould have looked like
+#' # this is what fig.2 in Bland&Altman1986 would have looked like
 #' PEFR1 <- bland.altman.PEFR[,1]
 #' PEFR2 <- bland.altman.PEFR[,3]
 #' bland.altman.plot(PEFR1, PEFR2, silent=TRUE, xlim=c(0,800),
@@ -162,6 +166,7 @@ bland.altman.stats <- function(group1, group2, two=1.96, mode=1, conf.int=.95){
 #'                   ylab="Difference in PEFR (large-mini)")
 #' 
 #' # and this is the same but with additional 95 percent CIs
+#' data(bland.altman.PEFR)
 #' bland.altman.plot(PEFR1, PEFR2, silent=TRUE, conf.int=.95, xlim=c(0,800))
 #'                   
 #' # an example with many ties and the 'sunflower'-option
@@ -170,25 +175,27 @@ bland.altman.stats <- function(group1, group2, two=1.96, mode=1, conf.int=.95){
 #' bland.altman.plot(a,b,sunflower=TRUE, xlab="Mean",ylab="Difference",
 #'                   main="discrete values lead to ties")
 #'                   
-#' # only very basic support for ggplot2 yet:
 #' library(ggplot2)
 #' a <- bland.altman.plot(rnorm(20), rnorm(20), graph.sys="ggplot2", conf.int=.9)
 #' print(a + xlab("you can change this later") + ggtitle("Title goes here"))                  
 bland.altman.plot <- function(group1, group2, two=1.96, mode=1,
                               graph.sys="base", conf.int=0, silent=TRUE,
-                              sunflower = FALSE, ...){
+                              sunflower = FALSE, geom_count=FALSE, ...){
     if(graph.sys=="base")
         return(bland.altman.base(group1, group2, two, mode, conf.int, 
-                                 silent, sunflower, ...))
+                                 silent, sunflower, geom_count, ...))
     if(graph.sys=="ggplot2")
         return(bland.altman.ggplot2(group1, group2, two, mode, conf.int, 
-                                 silent, sunflower, ...))
-    stop("WARNING: graph.sys must be element of c('base','ggplot2).")
+                                 silent, sunflower, geom_count, ...))
+    stop("ERROR: graph.sys must be element of c('base','ggplot2').")
 } 
  
   
 bland.altman.base <- function(group1, group2, two, mode, conf.int, 
-                               silent, sunflower, ...){
+                               silent, sunflower, geom_count, ...){
+    if(geom_count)
+        warning("bland.altman.base: No geom_count option for base graphics implemented.")
+    
     ba <- bland.altman.stats(group1 = group1, group2 = group2, two=two, 
                              mode = mode, conf.int=conf.int)
     if(sunflower==TRUE){
@@ -207,9 +214,9 @@ bland.altman.base <- function(group1, group2, two, mode, conf.int,
         ymin <- min(c(ba$diffs, ba$CI.lines))
         ymax <- max(c(ba$diffs, ba$CI.lines))
         plotfun(ba$means, ba$diffs, ylim=c(ymin,ymax),...)
-        abline(h=ba$lines, lty=2, col=c("blue","red","blue"),lwd=2)
-        abline(h=ba$CI.lines[c(1,2,5,6)], lty=3, col="blue")
-        abline(h=ba$CI.lines[c(3,4)], lty=3, col="red")
+        abline(h=ba$lines, lty=2, col=c("blue","red","blue"),lwd=3)
+        abline(h=ba$CI.lines[c(1,2,5,6)], lty=2, col="darkblue", lwd=2)
+        abline(h=ba$CI.lines[c(3,4)], lty=2, col="darkred", lwd=2)
     }
    
     if(silent==FALSE)
@@ -219,23 +226,26 @@ bland.altman.base <- function(group1, group2, two, mode, conf.int,
 }
 
 bland.altman.ggplot2 <- function(group1, group2, two, mode, conf.int, 
-                              silent, sunflower, ...){
+                              silent, sunflower, geom_count, ...){
     if(sunflower)
-        warning("No sunflower option in ggplot2 implemented yet.")
+        warning("bland.altman.plot: No sunflower option for ggplot2 implemented.")
+    
     ba <- bland.altman.stats(group1 = group1, group2 = group2, two=two, 
                              mode = mode, conf.int=conf.int)
     if(!requireNamespace("ggplot2"))
         stop("Could not load ggplot2. Sorry.")
     values <- data.frame(m = ba$means, d = ba$diffs)
+    geom_my <- if(geom_count) ggplot2::geom_count
+               else ggplot2::geom_point
     m <- NULL; d <- NULL #this is useless but helps with CRAN tests ;-(
     p <- ggplot2::ggplot(values, ggplot2::aes(x=m, y=d))+
-         ggplot2::geom_point()+
-         ggplot2::geom_hline(yintercept=ba$lines, linetype=2)+
+         geom_my()+
+         ggplot2::geom_hline(yintercept=ba$lines, linetype=2, size=1.0)+
          ggplot2::xlab("mean of measurements")+
          ggplot2::ylab("difference")
     if(conf.int>0){
-        p <- p+ggplot2::geom_hline(yintercept=ba$CI.lines, linetype=3)
+        p <- p+ggplot2::geom_hline(yintercept=ba$CI.lines, linetype=2, size=0.7)
     }
-    print(p)
+    #print(p)   # deleted after version 0.2.1
     return(p)
 }
\ No newline at end of file
